Learn R Programming

NLP (version 0.1-7)

ngrams: Compute N-Grams

Description

Compute the $n$-grams (contiguous sub-sequences of length $n$) of a given sequence.

Arguments

x
a sequence (vector).
n
a positive integer giving the length of contiguous sub-sequences to be computed

Value

  • a list with the computed sub-sequences.

Examples

Run this code
s <- "The quick brown fox jumps over the lazy dog"
## Split into words:
w <- strsplit(s, "", fixed = TRUE)[[1L]]
## Word tri-grams:
ngrams(w, 3L)
## Word tri-grams pasted together:
vapply(ngrams(w, 3L), paste, "", collapse = "")

Run the code above in your browser using DataLab